import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'default_page.dart';

class LoadingPage extends StatefulWidget {
  const LoadingPage({super.key});

  @override
  State<StatefulWidget> createState() => _LoadingPageState();
}

class _LoadingPageState extends State<LoadingPage>
    with SingleTickerProviderStateMixin{

  @override
  void initState() {
    super.initState();
    // Remove app bar
    SystemChrome.setEnabledSystemUIMode(SystemUiMode.immersive);

    // Hold loading page for 5 seconds before navigating to the default page
    Future.delayed(const Duration(seconds: 5), () {
      Navigator.of(context).pushReplacement(MaterialPageRoute(
        builder: (_) => const DefaultPage(),
        )
      );
    });
  }

  @override
  void dispose() { // Add back app bar
    super.dispose();
    SystemChrome.setEnabledSystemUIMode(
        SystemUiMode.manual,
        overlays: SystemUiOverlay.values,
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        width: double.infinity,
        decoration: const BoxDecoration( // Loading screen
          gradient: LinearGradient(
              colors: [Colors.grey, Colors.black],
              begin: Alignment.topLeft,
              end: Alignment.bottomRight
          ),
        ),
        child: Column(
          children: [
            Image.asset(
              'assets/icons/frozen.png', // Loading screen icon
              // Icon from: https://www.flaticon.com/free-icons/cold-water"
              color: Colors.grey,
            ),
            const SizedBox(height: 20),
            const Text(
              "IceMap",
              style: TextStyle(
                  color: Colors.white70,
                  fontStyle: FontStyle.italic,
              ),
            )
          ]
        ),
      ),
    );
  }
}